Module sys
Source - Timespec
- A record specifying a time value in seconds and nanoseconds, where
nanoseconds represent the offset from the given second.
- Tm
- Holds a calendar date and time broken down into its components (year, month,
day, and so on), also called a broken-down time value.